var chart; // globally available

function plotThreeDayData(dayOneData, dayTwoData, dayThreeData, rangeLow, rangeHigh) {
    cleanedDayOneData = cleanData(dayOneData);
    cleanedDayTwoData = cleanData(dayTwoData);
    cleanedDayThreeData = cleanData(dayThreeData);
    cleanedLow = cleanData(rangeLow);
    cleanedHigh = cleanData(rangeHigh);
    
    chart.series[0].setData(cleanedHigh, false);
    chart.series[1].setData(cleanedLow, false);
   
    chart.series[2].setData(cleanedDayOneData, false);
    
    if (cleanedDayTwoData.length > 0) {
        chart.series[3].setData([cleanedDayOneData.pop()].concat(cleanedDayTwoData), false);
    }
    
    if (cleanedDayThreeData.length > 0) {
        chart.series[4].setData([cleanedDayTwoData.pop()].concat(cleanedDayThreeData), false);
    }
    
    chart.redraw();
}

$(document).ready(function() {
    unitConversionFactor = function() {
                                try {
                                    return AndroidBridge.getBgUnitOfMeasureConversionFactor();
                                } catch(err) {
                                }
                           }();
                           
    unitScaleFactor = function() {
                            try {
                                return AndroidBridge.getBgUnitScaleFactor();
                            } catch(err) {
                            }
                      }();
                      
    localizedDecimal = function() {
                            try {
                                return new String(AndroidBridge.getLocalizedDecimal());
                            } catch(err) {
                            }
                       }();
                       
    Highcharts.setOptions({
      lang: {
          decimalPoint: localizedDecimal
      }
    });
    
    chart = new Highcharts.Chart({
        chart: {
            renderTo: 'trend-graph',
            type: 'bar',
            margin: [20, 11, 0, 50],
            borderRadius: 0,
            plotBackgroundColor: "#FFFFFF",
            animation: false,
            height: 250,
            width: 960,
            events: {
                load: function() {
                        try {
                            setTimeout(function(){AndroidBridge.onGraphFinishedLoading();}, 2000);
                        } catch(err) {
                        }
                }
            }
         },
         
        plotOptions: {
            series: {
                states: {
                    hover: {
                        enabled: false
                    }
                },
                pointPadding: 0,
                groupPadding: 0,
                borderWidth: 0, 
                shadow: false,
                animation: false
            },
            line: {
                lineWidth: 3,
                animation: false,
                enableMouseTracking: false
            },
            column: {
                stacking: "normal",
                borderWidth: 0,
                pointPadding: 0,
                groupPadding: 0,
                shadow: false,
                animation: false
            }
        },
        legend: {
            enabled: false
        },        
        credits: {
            enabled: false
        },
         
        tooltip: {
            enabled: false
        },
         
        title: {
            text: null
        },
         
        xAxis: {
            labels: {
                enabled: false
            },
            plotBands: [
                        {
			            	color: 'rgba(223, 240, 255, 1.0)',
			            	from: 0.5,
			            	to: 1.5
                        },
                        {
			            	color: 'rgba(223, 240, 255, 1.0)',
			            	from: 2.5,
			            	to: 3.5
                        },
                        {
			            	color: 'rgba(223, 240, 255, 1.0)',
			            	from: 4.5,
			            	to: 5.5
                        },
                        {
			            	color: 'rgba(223, 240, 255, 1.0)',
			            	from: 5.52,
			            	to: 6.5
                        },
                        {
			            	color: 'rgba(223, 240, 255, 1.0)',
			            	from: 7.5,
			            	to: 8.5
                        },
                        {
			            	color: 'rgba(223, 240, 255, 1.0)',
			            	from: 9.5,
			            	to: 10.5
                        },
                        {
			            	color: 'rgba(223, 240, 255, 1.0)',
			            	from: 11.5,
			            	to: 12.5
                        },
                        {
			            	color: 'rgba(223, 240, 255, 1.0)',
			            	from: 12.53,
			            	to: 13.5
                        },
                        {
			            	color: 'rgba(223, 240, 255, 1.0)',
			            	from: 14.5,
			            	to: 15.5
                        },
                        {
			            	color: 'rgba(223, 240, 255, 1.0)',
			            	from: 16.5,
			            	to: 17.5
                        },
                        {
			            	color: 'rgba(223, 240, 255, 1.0)',
			            	from: 18.5,
			            	to: 19.5
                        },
                        {
			            	color: 'rgba(223, 240, 255, 1.0)',
			            	from: 19.51,
			            	to: 20.5
                        }
                    ],
            maxPadding: 0.05,
            minPadding: 0.05,
            gridLineWidth: 0,
            lineWidth: 1,
            lineColor: "#D0E5F8",
            tickLength: 0,
            categories: [1, 2, 3, 4],
            plotLines: [
                {
                    color: "#000000",
                    width: 1,
                    value: 6.5
                },
                {
                    color: "#000000",
                    width: 1,
                    value: 13.51
                },
                {
                    color: "#FFFFFF",
                    width: 1,
                    value: 5.5
                },
                {
                    color: "#FFFFFF",
                    width: 1,
                    value: 12.5
                },
                {
                    color: "#FFFFFF",
                    width: 1,
                    value: 19.5
                }
            ]
        },
         
        yAxis: {
            title: {
               text: null
            },
            labels: {
                formatter: function() {
                    var number = Math.round(this.value / unitConversionFactor * 10) / 10;
                    return Highcharts.numberFormat(number, unitScaleFactor);
                },
                style: {
                    color: "black",
                    fontSize: "20px"
                }
            },
            gridLineWidth: 1,
            lineWidth: 1,
            lineColor: "#D0E5F8",
            gridLineColor: "#D0E5F8",
            plotLines: [
                {
                    color: "#FF3333",
                    width: 4,
                    zIndex: 10,
                    value: AndroidBridge.getHypoLine(),                  
                }
            ],
            min: -10,
            max: 310,
            endOnTick: false,
            startOnTick: false,
            tickInterval: 50
        },

        series: [            
            {
                data: [],
                name: "high",
                type: "column",
                showInLegend: false,
                color: "rgba(27,224,73,0.4)",
                borderWidth: 2,
                borderColor: "rgba(27,224,73,0.4)"
            },
            {
                data: [],
                name: "low",
                type: "column",
                showInLegend: false,
                color: "rgba(0,0,0,0)"
            },
            {
                data: [],
                name: "day1",
                type: "line",
                showInLegend: false,
                color: "#D42A89"
            },
            {
                data: [],
                name: "day2",
                type: "line",
                showInLegend: false,
                color: "#20BDC6"
            },
            {
                data: [],
                name: "day3",
                type: "line",
                showInLegend: false,
                color: "#FA8E01"
            }
        ]
      });
      
      try {
        AndroidBridge.loadThreeDayReportGraph();
      } catch(err) {
      }
});
