var chart; // globally available

function plotBgTrend(data) {
    cleanedBgData = cleanData(data);

    chart.series[0].setData(cleanedBgData, false);
            
    chart.redraw();
}

$(document).ready(function() {

    unitConversionFactor = 
        function() {
            try {
                return AndroidBridge.getBgUnitOfMeasureConversionFactor();
            } catch(err) {
            }
        }();
            
    unitScaleFactor = 
        function() {
            try {
                return AndroidBridge.getBgUnitScaleFactor();
            } catch(err) {
            }
        }();
            
    localizedMonths = 
        function() {
            try {
                return new String(AndroidBridge.getLocalizedShortMonthNames()).split(',');
            } catch(err) {
            }
        }();
        
    localizedDecimal = 
        function() {
            try {
                return new String(AndroidBridge.getLocalizedDecimal());
            } catch(err) {
            }
        }();
        
    localizedDateFormat = 
        function() {
            try {
                return new String(AndroidBridge.getLocalizedDateFormat());
            } catch(err) {
            }
        }();
        
    Highcharts.setOptions({
        lang: {
            shortMonths: localizedMonths,
            decimalPoint: localizedDecimal
        }
    });
    
    chart = new Highcharts.Chart({
        chart: {
            renderTo: 'trend-graph',
            type: 'bar',
            margin: [10, 20, 40, 70],
            height: 400,
            width: 900,
            zoomType: 'x',
            borderRadius: 0,
            animation: false,
            events: {
                load: function() {
                        try {
                            setTimeout(function(){AndroidBridge.onGraphFinishedLoading();}, 2000);
                        } catch(err) {
                        }
                }
            }
         },
         
        plotOptions: {
            series: {
                marker: {
                    enabled: true,
                    symbol: 'circle',
                    fillColor: 'white'
                }
            },
            line: {
                allowPointSelect: true,
                lineWidth: 3,
                animation: false
            },
            scatter: {
                allowPointSelect: true,
                animation: false
            }
        },
                
        legend: {
            enabled: false
        }, 
         
        credits: {
            enabled: false
        },
         
        tooltip: {
            enabled: false
        },
         
        title: {
            text: null
        },

        xAxis: [{
            labels: {
                style: {
                    color: "black",
                    fontSize: "12px"
                },
                y: 35
            },
            gridLineWidth: 1,
            lineWidth: 2,
            lineColor: "black",
            type: 'datetime',
            endOnTick: true,
            startOnTick: true,
            showLastLabel: true,
            dateTimeLabelFormats: {
                hour: localizedDateFormat + '%H:%M',
                day: localizedDateFormat,
                week: localizedDateFormat
            },
            tickInterval: AndroidBridge.getTickInterval(),
            min: AndroidBridge.getStartTime(),
            max: AndroidBridge.getEndTime()
        }],
         
        yAxis: {
            title: {
               text: new String(AndroidBridge.getYAxisTitle()),
               style: {
                   color: "black",
                   fontSize: "12px"
               },
            },
            labels: {
                formatter: function() {
                    var number = Math.round(this.value / unitConversionFactor * 10) / 10;
                    return Highcharts.numberFormat(number, unitScaleFactor);
                },
                style: {
                    color: "black",
                    fontSize: "20px"
                },
                y: 5          
            },
            gridLineWidth: 2,
            lineWidth: 2,
            lineColor: "black",
            gridLineColor: "#CECECE",
            maxZoom: 30,
            min: 0,
            max: 310,
            tickInterval: 50,
            endOnTick: false,
            startOnTick: true,
            plotBands: [
                        {
                            color: 'rgb(87, 159, 221)',
                            value: AndroidBridge.getBgTargetHigh(),
                            width: 2,
                            zIndex: 1,
                        },
                        {
                            color: 'rgb(210, 65, 81)',
                            value: AndroidBridge.getHypoLine(),
                            width: 2,
                            zIndex: 1,
                        },
                        {
                            color: 'rgb(255, 241, 149)',
                            value: AndroidBridge.getBgTargetLow(),
                            width: 2,
                            zIndex: 1,
                            
                        },
                    ],
        },

        series: [
            {
                data: [],
                type: "line",
                showInLegend: false,
                color: "black"
            }
        ]
      });
      
        try {
            AndroidBridge.loadBgTrendReportGraph();
        } catch(err) {
        }
});
